From c5dd8e23416e09aa63dea2ab574a42b7f30b7567 Mon Sep 17 00:00:00 2001
From: Anthonin Bonnefoy <anthonin.bonnefoy@datadoghq.com>
Date: Fri, 30 Aug 2024 14:45:30 +0200
Subject: Add LLVM_CPPFLAGS in headerscheck to llvm jit files

headerscheck on the CI currently works because the required llvm include
files are located in /usr/include (like /usr/include/llvm-c/Core.h).
However, it is very likely that those files will be located in a version
specific directory and llvm-config should be used to get the correct
cppflag using "$LLVM_CONFIG --cppflags".

Those flags are available in configure as LLVM_CPPFLAGS so we can add
them as extra flags for the headerscheck test command. This will allow
to run headerscheck on systems that don't have llvm include files in
/usr/include
---
 src/tools/pginclude/headerscheck | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/src/tools/pginclude/headerscheck b/src/tools/pginclude/headerscheck
index a78e16888a6..59fa4363ab7 100755
--- a/src/tools/pginclude/headerscheck
+++ b/src/tools/pginclude/headerscheck
@@ -43,6 +43,7 @@ CXXFLAGS=${CXXFLAGS:- -fsyntax-only -Wall}
 # Pull some info from configure's results.
 MGLOB="$builddir/src/Makefile.global"
 CPPFLAGS=`sed -n 's/^CPPFLAGS[ 	]*=[ 	]*//p' "$MGLOB"`
+LLVM_CPPFLAGS=`sed -n 's/^LLVM_CPPFLAGS[ 	]*=[ 	]*//p' "$MGLOB"`
 CFLAGS=`sed -n 's/^CFLAGS[ 	]*=[ 	]*//p' "$MGLOB"`
 CC=`sed -n 's/^CC[ 	]*=[ 	]*//p' "$MGLOB"`
 CXX=`sed -n 's/^CXX[ 	]*=[ 	]*//p' "$MGLOB"`
@@ -236,6 +237,8 @@ do
 		EXTRAINCLUDES="$python_includespec" ;;
 	    src/interfaces/ecpg/*)
 		EXTRAINCLUDES="-I $builddir/src/interfaces/ecpg/include -I $srcdir/src/interfaces/ecpg/include" ;;
+	    src/include/jit/*)
+		EXTRAINCLUDES="$LLVM_CPPFLAGS" ;;
 	    src/backend/parser/*)
 		EXTRAINCLUDES="-I $builddir/src/backend/parser/" ;;
 	    src/backend/utils/adt/*)
-- 
2.39.3 (Apple Git-146)

